import QtQuick 2.0
import Ubuntu.Components 0.1

FocusScope {
    id: multiRangeView

    property alias model: list.model
    property alias count: list.count
    property int cellWidth: Math.floor(width / count)

    /* Keep track of active cells with array, from which determine index
        of leftmost and rightmost active cells.*/
    property variant activeCells: new Array(count)
    property int leftActiveCell: -1
    property int rightActiveCell: -1

    function cellActivationChanged(cellId, state) {
        var tmp = activeCells
        tmp[cellId] = state
        activeCells = tmp
        setSelectionBarPosition()
    }

    function setSelectionBarPosition() {
        leftActiveCell = activeCells.indexOf(true)
        rightActiveCell = activeCells.lastIndexOf(true);
    }

    Rectangle {
        id: container
        x: Math.floor(border.width / 2)
        y: Math.floor(border.width / 2)
        width: parent.width - border.width
        height: parent.height - border.width
        border.color: "#20ffffff"
        border.width: 1
        color: "transparent"
        radius: 5
    }

    ListView {
        id: list
        anchors.fill: parent
        orientation: ListView.Horizontal
        focus: true
        boundsBehavior: Flickable.StopAtBounds
        delegate: Button {
            height: ListView.view.height
            width: cellWidth
            text: name
        }
    }
}
