/*
 * This file is part of unity-2d
 *
 * Copyright 2010-2011 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Unity 0.1
import "../"
FocusScope {
    id: filterLoader
    objectName: filterRenderName
//    property variant lens
//    property variant filterModel
//    property bool isFirst
    property string filterRenderName
    property string filterId
    property string filterName
    property string filterIconHint
    property bool  filterVisible
    property string filterCollapsed
    property string filterFiltering
    property variant filterOptions
    height: childrenRect.height

    FocusScope {
        id: header

        function accessibleDescription() {
            if (filterFiltering) {
                return filterName
            } else {
                return filterName
            }
        }

        Accessible.name: accessibleDescription()

//        KeyNavigation.down: filterView

        focus: true
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        height: childrenRect.height

        Rectangle {
            id: separatorLine

            color: "#ffffff"

            height: 188
//            visible: !isFirst
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right
        }

        Text{
            id: title
            anchors.verticalCenter: clearButton.verticalCenter
            anchors.topMargin:  13
            anchors.left: parent.left

            text: filterName
            font.pixelSize: 12
            font.bold: true
            font.underline: ( parent.state == "selected" || parent.state == "hovered" )
        }

        TickBox {
            id: clearButton
            focus: true
            width: Math.min(100, (10 * 3) + 18)
            height: 30
            anchors.top: parent.top
            anchors.topMargin:  13
            anchors.right: parent.right

            text: "All"
            checked: !filterFiltering
            onClicked: filterOptions.clear()
        }
    }

    Loader {
        id: filterView
        objectName: filterRenderName
width:  200
height: 1200
        //        anchors{
//            top: header.bottom
//            topMargin: 15
//            left: parent.left
//            right: parent.right
//        }
     source: {
                           if (filterRenderName === "filter-multirange")
                               "FilterMultirange.qml"
                           if (filterRenderName === "filter-checkoption")
                               "FilterCheckoption.qml"
                           if (filterRenderName === "filter-checkoption-compact")
                               "FilterCheckoptionCompact.qml"
                           if (filterRenderName === "filter-radiooption")
                               "FilterRadiooption.qml"
                   else
                               "FilterCheckoption.qml"
                           }
        onStatusChanged: {
            if (status == Loader.Error) {
                console.log("Failed to load filter renderer" +  filterRenderName )
            }
        }

        Binding { target: filterView.item; property: "options"; value: filterOptions }
        Binding { target: filterView.item; property: "name"; value: filterName }
        Binding { target: filterView.item; property: "iconHint"; value: filterIconHint }
        Binding { target: filterView.item; property: "visable"; value: filterVisible }
        Binding { target: filterView.item; property: "collapsed"; value: filterCollapsed }
        Binding { target: filterView.item; property: "filtering"; value: filterFiltering }
        onLoaded: item.focus = true
    }
}
